searchData={"items":[{"type":"module","title":"Inject","doc":"","ref":"Inject.html"},{"type":"function","title":"Inject.i/1","doc":"","ref":"Inject.html#i/1"},{"type":"function","title":"Inject.inject/1","doc":"","ref":"Inject.html#inject/1"},{"type":"function","title":"Inject.register/3","doc":"","ref":"Inject.html#register/3"},{"type":"module","title":"Inject.Application","doc":"","ref":"Inject.Application.html"},{"type":"function","title":"Inject.Application.start/2","doc":"","ref":"Inject.Application.html#start/2"},{"type":"extras","title":"Inject","doc":"# Inject\n\nInject is a library that lets you write testable Elixir code that can run concurrently in ExUnit.","ref":"readme.html"},{"type":"extras","title":"Installation - Inject","doc":"```elixir\ndef deps do\n  [\n    {:inject, \"~> 0.4.1\"}\n  ]\nend\n```\n\nIt is recommended to disable inject in prod.exs to avoid any performance penalty for registry lookups.\n\n```\nconfig :inject, disabled: true\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Inject","doc":"Inject is just a couple of functions.\n\n- `inject/1` aliased as `i/1`. Use this function in your implementation code to flag modules for potential injection.\n\n```elixir\ndefmodule MyApplication do\n  import Inject, only: [i: 1]\n\n  def process do\n    {:ok, file} = i(File).open(\"your-mind.txt\", [])\n    ...\n  end\nend\n```\n\n- `register/2` `register/3`. Use this function in your tests to register a stubbed implementation for a module.\n\n```elixir\ndefmodule MyApplicationTest do\n  use ExUnit.Case, async: true\n  import Inject, only: [register: 2]\n\n  defmodule FileStub do\n    def open(\"your-mind.txt\", _opts) do\n      {:ok, nil}\n    end\n  end\n\n  test \"use my stub for this test\" do\n    register(File, FileStub)\n    {:ok, nil} = MyApplication.process()\n  end\nend\n```\n\nDefining stubbed modules like this is great, but I like to pair Inject w/ [Double](https://hex.pm/packages/double) for on-the-fly setups.\n\n```elixir\ndefmodule MyApplicationTest do\n  use ExUnit.Case, async: true\n  import Inject, only: [register: 2]\n  import Double\n\n  test \"use my stub for this test\" do\n    register(File, stub(File, :open, fn(_, _) -> {:ok, nil} end))\n    {:ok, nil} = MyApplication.process()\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Shared Mode - Inject","doc":"If you want to inject a dependency that will be shared by all processes, you can do so by passing the `shared: true` option.\nThis can be useful if you have background processing. This is only recommended for tests that do not run async.\n\n```elixir\nregister(File, FileStub, shared: true)\n```","ref":"readme.html#shared-mode"},{"type":"extras","title":"TODO - Inject","doc":"- Add `allow/1` for enabling another process to use registrations from the current test.","ref":"readme.html#todo"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}